@@ -1,6 +1,5 @@
 """Object-specific python package to run automated tasks in the Chase Lab."""
-import warnings
-warnings.filterwarnings("ignore")
+import warnings; warnings.filterwarnings("ignore")
 from .ffsync import ffsync
 from .ffconcat import ffconcat
 from .lazytrim import lazytrim
@@ -17,5 +16,6 @@ from .obtain_grand_m import obtain_grand_m
 from .concat_csv import concat_csv
 from .calc_dlc_mw import calc_dlc_mw
 from .dlcboxplot import dlcboxplot
-
+from .turning_points import turning_points_output
+from .improve_turnpoints import improve_turnpoints
 from .version import __version__, VERSION
