@@ -1,4 +1,11 @@
-from toxopy import trials, fwarnings
+"""
+Toxopy (https://github.com/bchaselab/Toxopy)
+© M. Alyetama, University of Nebraska at Omaha
+Licensed under the terms of the MIT license
+"""
+
+import warnings; warnings.filterwarnings("ignore")
+from toxopy import trials
 import pandas as pd
 from scipy.stats import mannwhitneyu
 from os import remove
