@@ -1,4 +1,10 @@
-from toxopy import fwarnings
+"""
+Toxopy (https://github.com/bchaselab/Toxopy)
+© M. Alyetama, University of Nebraska at Omaha
+Licensed under the terms of the MIT license
+"""
+
+import warnings; warnings.filterwarnings("ignore")
 import pandas as pd
 import seaborn as sns
 import matplotlib.pyplot as plt
